@@ -30,6 +30,7 @@
 #include "oxygenstylewrapper.h"
 #include "oxygenwindecooptions.h"
 #include "oxygenwindowshadow.h"
+#include "oxygentimelineserver.h"
 
 #include <gmodule.h>
 #include <gtk/gtk.h>
@@ -69,6 +70,7 @@ void theme_exit( void )
 
     // delete style instance
     delete &Oxygen::Style::instance();
+    delete &Oxygen::TimeLineServer::instance();
 
 }
 
